<!--
This form is for feature requests ONLY!
If you're looking for help check out the [readme](/README.md).
-->
**Feature request**

**What does this feature / why does DuMux need it**:

**Which issue does this feature fix (if any)**

**Anything else we need to know?**:
